Gets taxonomic information of a GBIF dataset. Only source taxa are kept,
denormed higher classification taxa are removed. The function
rgbif::name_usage() is used under the hood.
Taxa details
get_taxa() returns a tibble with 8
variables:
taxonKey: GBIF taxon key within the checklistnubKey: GBIF backbone taxon keytaxonID: Taxon ID from the datasetscientificName: Scientific name of the taxon within the checklistacceptedKey: GBIF taxon key of the accepted taxon within the checklist, if applicableaccepted: Scientific name of the accepted taxon within the checklist, if applicablekingdom: Kingdom of the taxontaxonRank: Taxonomic rank of the taxon